@@ -7,7 +7,7 @@
 namespace LFortran {
 
     std::unique_ptr<LLVMModule> asr_to_llvm(ASR::asr_t &asr,
-            llvm::LLVMContext &context);
+            llvm::LLVMContext &context, Allocator &al);
 
 } // namespace LFortran
 
