@@ -9,6 +9,7 @@
 
 using LFortran::parse;
 using LFortran::parse2;
+using LFortran::tokens;
 using LFortran::AST::ast_t;
 using LFortran::AST::expr_t;
 using LFortran::AST::Name_t;
@@ -73,7 +74,7 @@ TEST_CASE("Test longer parser (N = 500)") {
     Allocator al(1024*1024);
     std::cout << "Parse" << std::endl;
     auto t1 = std::chrono::high_resolution_clock::now();
-    auto result = parse(al, text);
+    auto result = parse(al, text)->m_items[0];
     auto t2 = std::chrono::high_resolution_clock::now();
     std::cout << std::chrono::duration_cast<std::chrono::milliseconds>(t2 - t1)
                      .count()
@@ -85,21 +86,183 @@ TEST_CASE("Test longer parser (N = 500)") {
     CHECK(c == 4509);
 }
 
-std::vector<int> tokens(const std::string &input,
-        std::vector<LFortran::YYSTYPE> *stypes=nullptr)
-{
-    LFortran::Tokenizer t;
-    t.set_string(input);
-    std::vector<int> tst;
-    int token = yytokentype::END_OF_FILE + 1; // Something different from EOF
-    while (token != yytokentype::END_OF_FILE) {
-        LFortran::YYSTYPE y;
-        LFortran::Location l;
-        token = t.lex(y, l);
-        tst.push_back(token);
-        if (stypes) stypes->push_back(y);
+TEST_CASE("Test LFortran::Vec") {
+    Allocator al(1024);
+    LFortran::Vec<int> v;
+
+    v.reserve(al, 2);
+    CHECK(v.size() == 0);
+    CHECK(v.capacity() == 2);
+
+    v.push_back(al, 1);
+    CHECK(v.size() == 1);
+    CHECK(v.capacity() == 2);
+    CHECK(v.p[0] == 1);
+    CHECK(v[0] == 1);
+
+    v.push_back(al, 2);
+    CHECK(v.size() == 2);
+    CHECK(v.capacity() == 2);
+    CHECK(v.p[0] == 1);
+    CHECK(v.p[1] == 2);
+    CHECK(v[0] == 1);
+    CHECK(v[1] == 2);
+
+    v.push_back(al, 3);
+    CHECK(v.size() == 3);
+    CHECK(v.capacity() == 4);
+    CHECK(v.p[0] == 1);
+    CHECK(v.p[1] == 2);
+    CHECK(v.p[2] == 3);
+    CHECK(v[0] == 1);
+    CHECK(v[1] == 2);
+    CHECK(v[2] == 3);
+
+    v.push_back(al, 4);
+    CHECK(v.size() == 4);
+    CHECK(v.capacity() == 4);
+    CHECK(v.p[0] == 1);
+    CHECK(v.p[1] == 2);
+    CHECK(v.p[2] == 3);
+    CHECK(v.p[3] == 4);
+    CHECK(v[0] == 1);
+    CHECK(v[1] == 2);
+    CHECK(v[2] == 3);
+    CHECK(v[3] == 4);
+
+    v.push_back(al, 5);
+    CHECK(v.size() == 5);
+    CHECK(v.capacity() == 8);
+    CHECK(v.p[0] == 1);
+    CHECK(v.p[1] == 2);
+    CHECK(v.p[2] == 3);
+    CHECK(v.p[3] == 4);
+    CHECK(v.p[4] == 5);
+    CHECK(v[0] == 1);
+    CHECK(v[1] == 2);
+    CHECK(v[2] == 3);
+    CHECK(v[3] == 4);
+    CHECK(v[4] == 5);
+
+
+    std::vector<int> sv = v.as_vector();
+    CHECK(sv.size() == 5);
+    CHECK(&(sv[0]) != &(v.p[0]));
+    CHECK(sv[0] == 1);
+    CHECK(sv[1] == 2);
+    CHECK(sv[2] == 3);
+    CHECK(sv[3] == 4);
+    CHECK(sv[4] == 5);
+}
+
+TEST_CASE("LFortran::Vec iterators") {
+    Allocator al(1024);
+    LFortran::Vec<int> v;
+
+    v.reserve(al, 2);
+    v.push_back(al, 1);
+    v.push_back(al, 2);
+    v.push_back(al, 3);
+    v.push_back(al, 4);
+
+    // Check reference (auto)
+    int i = 0;
+    for (auto &a : v) {
+        i += a;
     }
-    return tst;
+    CHECK(i == 10);
+
+    // Check reference (must be const)
+    i = 0;
+    for (const int &a : v) {
+        i += a;
+    }
+    CHECK(i == 10);
+
+    // Check direct type (auto)
+    i = 0;
+    for (auto a : v) {
+        i += a;
+    }
+    CHECK(i == 10);
+
+    // Check direct type (const)
+    i = 0;
+    for (const int a : v) {
+        i += a;
+    }
+    CHECK(i == 10);
+
+    // Check direct type (non const)
+    i = 0;
+    for (int a : v) {
+        i += a;
+    }
+    CHECK(i == 10);
+}
+
+TEST_CASE("Test LFortran::Str") {
+    Allocator al(1024);
+    LFortran::Str s;
+    const char *data = "Some string.";
+
+    s.p = const_cast<char*>(data);
+    s.n = 2;
+    CHECK(s.size() == 2);
+    CHECK(s.p == data);
+    CHECK(s.str() == "So");
+
+    std::string scopy = s.str();
+    CHECK(s.p != &scopy[0]);
+    CHECK(scopy == "So");
+    CHECK(scopy[0] == 'S');
+    CHECK(scopy[1] == 'o');
+    CHECK(scopy[2] == '\x00');
+
+    char *copy = s.c_str(al);
+    CHECK(s.p != copy);
+    CHECK(copy[0] == 'S');
+    CHECK(copy[1] == 'o');
+    CHECK(copy[2] == '\x00');
+}
+
+TEST_CASE("Test LFortran::Allocator") {
+    Allocator al(32);
+    // Size is what we asked (32) plus alignment (8) = 40
+    CHECK(al.size_total() == 40);
+
+    // Fits in the pre-allocated chunk
+    al.alloc(32);
+    CHECK(al.size_total() == 40);
+
+    // Chunk doubles
+    al.alloc(32);
+    CHECK(al.size_total() == 80);
+
+    // Chunk doubles
+    al.alloc(90);
+    CHECK(al.size_total() == 160);
+
+    // We asked more than can fit in the doubled chunk (2*160),
+    // so the chunk will be equal to what we asked (1024) plus alignment (8)
+    al.alloc(1024);
+    CHECK(al.size_total() == 1032);
+}
+
+TEST_CASE("Test LFortran::Allocator 2") {
+    Allocator al(32);
+    int *p = al.allocate<int>();
+    p[0] = 5;
+
+    p = al.allocate<int>(3);
+    p[0] = 1;
+    p[1] = 2;
+    p[2] = 3;
+
+    std::vector<int> *v = al.make_new<std::vector<int>>(5);
+    CHECK(v->size() == 5);
+    // Must manually call the destructor:
+    v->~vector<int>();
 }
 
 using tt = yytokentype;
@@ -961,7 +1124,7 @@ TEST_CASE("Location") {
     end subroutine)";
 
     Allocator al(1024*1024);
-    LFortran::AST::ast_t* result = parse(al, input);
+    LFortran::AST::ast_t* result = parse(al, input)->m_items[0];
     CHECK(result->loc.first_line == 1);
     CHECK(result->loc.first_column == 1);
     CHECK(result->loc.last_line == 4);
@@ -1000,7 +1163,7 @@ TEST_CASE("Location") {
     x = y
     x = 213*yz
     end function)";
-    result = parse(al, input);
+    result = parse(al, input)->m_items[0];
     CHECK(result->loc.first_line == 1);
     CHECK(result->loc.first_column == 1);
     CHECK(result->loc.last_line == 4);
@@ -1010,7 +1173,7 @@ TEST_CASE("Location") {
     x = y
     x = 213*yz
     end program)";
-    result = parse(al, input);
+    result = parse(al, input)->m_items[0];
     CHECK(result->loc.first_line == 1);
     CHECK(result->loc.first_column == 1);
     CHECK(result->loc.last_line == 4);
